# Contributing

If you encounter an issue or want to contribute to pyrekordbox, please feel free to get in touch,
open an [issue] or create a new [pull request][pulls]!

pyrekordbox is tested on Windows and MacOS, however some features can't be tested in
the CI setup since it requires a working Rekordbox installation. The auto-configuration
(discovering Rekordbox file locations) is tested on Windows, but help would be
appreciated on MacOS.

[issue]: https://github.com/dylanljones/pyrekordbox/issues
[pulls]: https://github.com/dylanljones/pyrekordbox/pulls
